@@ -18,7 +18,7 @@
 	Copyright (C) 2011 - 2015, Simon Hampe <simon.hampe@googlemail.com>
 
 	---
-	Copyright (c) 2016-2020
+	Copyright (c) 2016-2023
 	Ewgenij Gawrilow, Michael Joswig, and the polymake team
 	Technische Universität Berlin, Germany
 	https://polymake.org
@@ -100,10 +100,10 @@ void codim_one_with_locality(BigObject cycle)
   Matrix<Rational> lineality = cycle.give("LINEALITY_SPACE");
 
   // Create a proxy object without the local restriction
-  BigObject proxy("Cycle", mlist<Addition>());
-  proxy.take("PROJECTIVE_VERTICES") << rays;
-  proxy.take("MAXIMAL_POLYTOPES") << cones;
-  proxy.take("LINEALITY_SPACE") << lineality;
+  BigObject proxy("Cycle", mlist<Addition>(),
+                  "PROJECTIVE_VERTICES", rays,
+                  "MAXIMAL_POLYTOPES", cones,
+                  "LINEALITY_SPACE", lineality);
 
   // Extract non-local data
   IncidenceMatrix<> codim_one = proxy.give("CODIMENSION_ONE_POLYTOPES");
